Returns one row per observed time point with the quantities needed to compute Detection Probability (DP) and Detection Lag (DL).
Returns one row per observed time point with the quantities needed to compute Detection Probability (DP) and Detection Lag (DL).