| examples_changepoints | R Documentation |
A list of time series for change point experiments.
simple: simple synthetic series with one change point.
sinusoidal: sinusoidal pattern with a regime change.
incremental: gradual change in mean/variance.
abrupt: abrupt level shift.
volatility: variance change.
#'
data(examples_changepoints)
A list of time series for change point detection.
Ogasawara, E., Salles, R., Porto, F., Pacitti, E. Event Detection in Time Series. 1st ed. Cham: Springer Nature Switzerland, 2025. doi:10.1007/978-3-031-75941-3
data(examples_changepoints)
# Select a simple change point series
serie <- examples_changepoints$simple
head(serie)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.