Skip to contents

Uses the detector as already fitted and only calls detect() during the online loop. This is useful when the model is pre-trained or when warm-up fitting should happen only once.

Usage

har_online_detect_only(fit_on_warmup = FALSE)

Arguments

fit_on_warmup

Whether the detector should be fitted once after warm-up.

Value

A har_online_detect_only object.

Examples

exec <- har_online_detect_only()
exec$fit_each_run
#> [1] FALSE