| hmo_sax | R Documentation |
Discovers repeated subsequences (motifs) using a Symbolic Aggregate approXimation (SAX) representation doi:10.1007/s10618-007-0064-z. Subsequences are discretized and grouped by symbolic words; frequently occurring words indicate motifs.
hmo_sax(a, w, qtd = 2)
a |
Integer. Alphabet size. |
w |
Integer. Word/window size. |
qtd |
Integer. Minimum number of occurrences to classify as a motif. |
hmo_sax object.
Lin J, Keogh E, Lonardi S, Chiu B (2007). A symbolic representation of time series, with implications for streaming algorithms. Data Mining and Knowledge Discovery 15, 107–144.
library(daltoolbox)
# Load motif example data
data(examples_motifs)
# Use a simple sequence example
dataset <- examples_motifs$simple
head(dataset)
# Configure SAX-based motif discovery
model <- hmo_sax(26, 3, 3)
# Fit the model
model <- fit(model, dataset$serie)
# Run detection
detection <- detect(model, dataset$serie)
# Show detected motifs
print(detection[(detection$event),])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.