Skip to contents

Pushes one observation or a collection of observations into the session queue. This is the main entry point for push-style integrations.

Usage

ingest(obj, observation)

Arguments

obj

Online session.

observation

One observation, a list of observations, or a data frame. Each individual observation is normalized to the online observation contract used by next_observation().

Value

Updated har_online_session.