Learn R Programming

harbinger (version 1.2.767)

ucr_power_demand: UCR Anomaly Archive – Italian Power Demand

Description

Data collection with real-world time-series. Real power demand time series with labeled anomalous intervals. See cefet-rj-dal/united for detailed guidance on using this package and the other datasets available in it. Labels available? Yes

Usage

data(ucr_power_demand)

Arguments

Format

A list of time series.

Details

This package ships a mini version of the dataset. Use loadfulldata() to download and load the full dataset from the URL stored in attr(url).

References

UCR Time Series Anomaly Archive. See also: Chandola, V., Banerjee, A., & Kumar, V. (2009). Anomaly detection: A survey. ACM Computing Surveys, 41(3), 1–58.

Examples

Run this code
data(ucr_power_demand)
s <- ucr_power_demand[[1]]
summary(s$value)

Run the code above in your browser using DataLab