R/har_online_session.R
collect_detection.Rd
Materializes the final detection table from the online session trace.
collect_detection(obj)
Online session.
A data frame with the usual idx, event, and type columns plus online summary columns:
idx
event
type
detection_probability
detection_lag_batches
detection_lag_observations