View source: R/har_online_session.R
| collect_detection | R Documentation |
Materializes the final detection table from the online session trace.
collect_detection(obj)
obj |
Online session. |
A data frame with the usual idx, event, and type columns plus
online summary columns:
detection_probability
detection_lag_batches
detection_lag_observations
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.