View source: R/har_online_session.R
| collect_trace | R Documentation |
Returns one row per observed time point with the quantities needed to compute Detection Probability (DP) and Detection Lag (DL).
collect_trace(obj)
obj |
Online session. |
Data frame with one row per observation and columns:
idx
timestamp
batch_id_first_seen
batch_frequency
detection_frequency
first_detected_batch
last_detected_batch
detection_probability
detection_lag_batches
detection_lag_observations
event_type
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.