| detect | R Documentation |
Generic S3 generic for event detection using a fitted Harbinger model. Concrete methods are implemented by each detector class.
detect(obj, ...)
obj |
A |
... |
Additional arguments passed to methods. |
A data frame with columns: idx (index), event (logical), and
type (character: "anomaly", "changepoint", or ""). Some detectors may
also attach attributes (e.g., threshold) or columns (e.g., seq, seqlen).
# See detector-specific examples in the package site for usage patterns
# and plotting helpers.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.