| hanct_dtw | R Documentation |
Distance-based anomaly and discord detection using dynamic time warping.
The detector clusters the series with DTW and flags observations or subsequences
that are far from the nearest centroid.
When seq equals one, isolated observations are labeled as anomalies.
When seq is greater than one, subsequences are labeled as discords.
Wraps the tsclust implementation from the dtwclust package.
hanct_dtw(seq = 1, centers = NA)
seq |
sequence size |
centers |
number of centroids |
hanct_dtw object
Ogasawara, E., Salles, R., Porto, F., Pacitti, E. Event Detection in Time Series. 1st ed. Cham: Springer Nature Switzerland, 2025. doi:10.1007/978-3-031-75941-3
library(daltoolbox)
# Load anomaly example data
data(examples_anomalies)
# Use a simple example
dataset <- examples_anomalies$simple
head(dataset)
# Configure DTW-based detector
model <- hanct_dtw()
# Fit the model
model <- fit(model, dataset$serie)
# Run detection
detection <- detect(model, dataset$serie)
# Show detected events
print(detection[(detection$event),])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.