| hanr_histogram | R Documentation |
Flags observations that fall into low-density histogram bins or outside the observed bin range.
hanr_histogram(density_threshold = 0.05)
density_threshold |
Numeric between 0 and 1. Minimum bin density to avoid being considered an anomaly (default 0.05). |
hanr_histogram object
Ogasawara, E., Salles, R., Porto, F., Pacitti, E. Event Detection in Time Series. 1st ed. Cham: Springer Nature Switzerland, 2025. doi:10.1007/978-3-031-75941-3
library(daltoolbox)
# Load anomaly example data
data(examples_anomalies)
# Use a simple example
dataset <- examples_anomalies$simple
head(dataset)
# Configure histogram-based detector
model <- hanr_histogram()
# Fit the model (no-op)
model <- fit(model, dataset$serie)
# Run detection
detection <- detect(model, dataset$serie)
# Show detected anomalies
print(detection[(detection$event),])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.