Score-based ensemble across multiple Harbinger detectors with optional temporal fuzzification, thresholding, and non-maximum suppression.
This variant preserves the richer aggregation logic that was previously mixed
into har_ensemble(), but keeps the simple majority-vote ensemble separate.
References
Ogasawara, E., Salles, R., Porto, F., Pacitti, E. Event Detection in Time Series. 1st ed. Cham: Springer Nature Switzerland, 2025. doi:10.1007/978-3-031-75941-3
Examples
library(daltoolbox)
data(examples_changepoints)
dataset <- examples_changepoints$simple
model <- har_ensemble_fuzzy(
hcp_scp(sw = 30),
hcp_chow(),
hcp_cf_arima(sw_size = 10)
)
model <- fit(model, dataset$serie)
detection <- detect(model, dataset$serie, time_tolerance = 8, use_nms = TRUE)
print(detection[detection$event, ])
#> idx event type
#> 50 50 TRUE