Visualize ensemble detection results and the individual model votes stored
by har_ensemble_fuzzy().
The plotting helpers do not recompute detections. They use the attributes attached to the detection object as the source of truth.
Visualize ensemble detection results and the individual model votes stored
by har_ensemble_fuzzy().
The plotting helpers do not recompute detections. They use the attributes attached to the detection object as the source of truth.