Uses the detector as already fitted and only calls detect() during the
online loop. This is useful when the model is pre-trained or when warm-up
fitting should happen only once.
Uses the detector as already fitted and only calls detect() during the
online loop. This is useful when the model is pre-trained or when warm-up
fitting should happen only once.