har_online_detect_only: Detect-only execution strategy

View source: R/har_online_executor.R

har_online_detect_onlyR Documentation

Detect-only execution strategy

Description

Uses the detector as already fitted and only calls detect() during the online loop. This is useful when the model is pre-trained or when warm-up fitting should happen only once.

Usage

har_online_detect_only(fit_on_warmup = FALSE)

Arguments

fit_on_warmup

Whether the detector should be fitted once after warm-up.

Value

A har_online_detect_only object.

Examples

exec <- har_online_detect_only()
exec$fit_each_run

harbinger documentation built on July 10, 2026, 5:07 p.m.