View source: R/har_online_executor.R
| har_online_detect_only | R Documentation |
Uses the detector as already fitted and only calls detect() during the
online loop. This is useful when the model is pre-trained or when warm-up
fitting should happen only once.
har_online_detect_only(fit_on_warmup = FALSE)
fit_on_warmup |
Whether the detector should be fitted once after warm-up. |
A har_online_detect_only object.
exec <- har_online_detect_only()
exec$fit_each_run
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.