Creates a replay source from an in-memory vector or data frame. This is the recommended source for reproducible streaming experiments and is the direct replacement for the simulated data flow used in the Nexus prototype.
Examples
source <- har_source_simulated(c(1, 2, 3))
obs <- next_observation(source)
obs$observation$value
#> [1] 1