View source: R/har_online_sources.R
| har_source_simulated | R Documentation |
Creates a replay source from an in-memory vector or data frame. This is the recommended source for reproducible streaming experiments and is the direct replacement for the simulated data flow used in the Nexus prototype.
har_source_simulated(data, timestamp = NULL, name = "simulated")
data |
Numeric vector, matrix, or data frame containing observations in time order. |
timestamp |
Optional vector with one timestamp per observation. |
name |
Source name. |
A har_source_simulated object.
source <- har_source_simulated(c(1, 2, 3))
obs <- next_observation(source)
obs$observation$value
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.