View source: R/har_online_session.R
| ingest | R Documentation |
Pushes one observation or a collection of observations into the session queue. This is the main entry point for push-style integrations.
ingest(obj, observation)
obj |
Online session. |
observation |
One observation, a list of observations, or a data frame.
Each individual observation is normalized to the online observation
contract used by |
Updated har_online_session.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.