Returns TRUE when there is no queued observation left and the pull source is
exhausted. In push mode, the session is considered finished when the queue is
empty.
Returns TRUE when there is no queued observation left and the pull source is
exhausted. In push mode, the session is considered finished when the queue is
empty.