is_finished: Test whether an online session has finished

View source: R/har_online_session.R

is_finishedR Documentation

Test whether an online session has finished

Description

Returns TRUE when there is no queued observation left and the pull source is exhausted. In push mode, the session is considered finished when the queue is empty.

Usage

is_finished(obj)

Arguments

obj

Online session.

Value

Logical scalar.


harbinger documentation built on July 10, 2026, 5:07 p.m.