View source: R/har_online_session.R
| is_finished | R Documentation |
Returns TRUE when there is no queued observation left and the pull source is
exhausted. In push mode, the session is considered finished when the queue is
empty.
is_finished(obj)
obj |
Online session. |
Logical scalar.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.