next_observation: Get the next observation from a source

View source: R/har_online_sources.R

next_observationR Documentation

Get the next observation from a source

Description

Generic used by Harbinger online sessions to request one observation in pull mode.

Usage

next_observation(obj, ...)

Arguments

obj

Source object.

...

Additional arguments passed to methods.

Value

A list with fields:

  • source: the updated source object;

  • observation: a normalized observation or NULL;

  • available: logical flag indicating whether a new observation was returned.


harbinger documentation built on July 10, 2026, 5:07 p.m.