View source: R/har_online_sources.R
| next_observation | R Documentation |
Generic used by Harbinger online sessions to request one observation in pull mode.
next_observation(obj, ...)
obj |
Source object. |
... |
Additional arguments passed to methods. |
A list with fields:
source: the updated source object;
observation: a normalized observation or NULL;
available: logical flag indicating whether a new observation was returned.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.