R/har_online_session.R
step_online.Rd
Consumes at most one new observation and triggers one batch detection cycle when the batch threshold is reached.
step_online(obj, ...)
Online session.
Additional arguments forwarded to wrapped detector methods.
Updated har_online_session.
har_online_session