| trans_sax | R Documentation |
Symbolic Aggregate approXimation (SAX) discretization of a numeric time series.
The series is z-normalized, quantile-binned, and mapped to an alphabet of size alpha.
trans_sax(alpha)
alpha |
Integer. Alphabet size (2–26). |
A trans_sax transformer object.
Lin J, Keogh E, Lonardi S, Chiu B (2007). A symbolic representation of time series, with implications for streaming algorithms. Data Mining and Knowledge Discovery 15, 107–144.
library(daltoolbox)
vector <- 1:52
model <- trans_sax(alpha = 26)
model <- fit(model, vector)
xvector <- transform(model, vector)
print(xvector)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.