Symbolic Aggregate approXimation (SAX) discretization of a numeric time series.
The series is z-normalized, quantile-binned, and mapped to an alphabet of size alpha.
Usage
trans_sax(alpha)
Value
A trans_sax transformer object.
Arguments
alpha
Integer. Alphabet size (2–26).
References
Lin J, Keogh E, Lonardi S, Chiu B (2007). A symbolic representation of time series,
with implications for streaming algorithms. Data Mining and Knowledge Discovery 15, 107–144.